format_subject_for_index

Function format_subject_for_index 

pub fn format_subject_for_index(subject: &str, config: &Config) -> String
Decode and strip the list tag from a subject, for use in both message and index pages.